[ARVADOS] updated: a3f380f9dfe25c1c28e6354de56d93b5c9265a08

git at public.curoverse.com git at public.curoverse.com
Wed Sep 17 11:36:59 EDT 2014


Summary of changes:
 apps/workbench/app/assets/javascripts/dates.js               |  1 -
 apps/workbench/app/helpers/pipeline_instances_helper.rb      |  1 -
 .../app/views/pipeline_instances/_show_tab_buttons.html.erb  |  2 +-
 apps/workbench/test/integration/pipeline_instances_test.rb   | 12 ++++++------
 4 files changed, 7 insertions(+), 9 deletions(-)

       via  a3f380f9dfe25c1c28e6354de56d93b5c9265a08 (commit)
      from  8b9f3b877a6aa7ed81db48f83f3feb5ef4388164 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit a3f380f9dfe25c1c28e6354de56d93b5c9265a08
Author: Peter Amstutz <peter.amstutz at curoverse.com>
Date:   Wed Sep 17 11:36:53 2014 -0400

    3187: Fix tests and some debug spew.

diff --git a/apps/workbench/app/assets/javascripts/dates.js b/apps/workbench/app/assets/javascripts/dates.js
index 9e484ce..4b90ab0 100644
--- a/apps/workbench/app/assets/javascripts/dates.js
+++ b/apps/workbench/app/assets/javascripts/dates.js
@@ -1,5 +1,4 @@
 $(document).on('ajax:complete arv:pane:loaded ready', function() {
-    console.log("woble!");
     $('[data-utc-date]').each(function(i, elm) {
         var re = /(\d\d\d\d)-(\d\d)-(\d\d) (\d\d):(\d\d):(\d\d) UTC/;
         var v = $(elm).attr('data-utc-date').match(re);
diff --git a/apps/workbench/app/helpers/pipeline_instances_helper.rb b/apps/workbench/app/helpers/pipeline_instances_helper.rb
index 995b1c3..b8b6125 100644
--- a/apps/workbench/app/helpers/pipeline_instances_helper.rb
+++ b/apps/workbench/app/helpers/pipeline_instances_helper.rb
@@ -59,7 +59,6 @@ module PipelineInstancesHelper
   end
 
   def determine_wallclock_runtime jobs
-    puts "Begin #{jobs}"
     timestamps = []
     jobs.each do |j|
       insert_at = 0
diff --git a/apps/workbench/app/views/pipeline_instances/_show_tab_buttons.html.erb b/apps/workbench/app/views/pipeline_instances/_show_tab_buttons.html.erb
index 9c0f28e..2e46581 100644
--- a/apps/workbench/app/views/pipeline_instances/_show_tab_buttons.html.erb
+++ b/apps/workbench/app/views/pipeline_instances/_show_tab_buttons.html.erb
@@ -1,4 +1,4 @@
-  <% if @object.state.in? ['Complete', 'Failed', 'Cancelled'] %>
+  <% if @object.state.in? ['Complete', 'Failed', 'Cancelled', 'Paused'] %>
 
   <%= link_to(copy_pipeline_instance_path('id' => @object.uuid, 'script' => "use_latest", "components" => "use_latest", "pipeline_instance[state]" => "RunningOnServer"),
       class: 'btn btn-primary',
diff --git a/apps/workbench/test/integration/pipeline_instances_test.rb b/apps/workbench/test/integration/pipeline_instances_test.rb
index e019813..538637d 100644
--- a/apps/workbench/test/integration/pipeline_instances_test.rb
+++ b/apps/workbench/test/integration/pipeline_instances_test.rb
@@ -74,14 +74,14 @@ class PipelineInstancesTest < ActionDispatch::IntegrationTest
 
     first('a,button', text: 'Run').click
 
-    # Pipeline is running. We have a "Stop" button instead now.
-    page.assert_selector 'a,button', text: 'Stop'
-    find('a,button', text: 'Stop').click
+    # Pipeline is running. We have a "Pause" button instead now.
+    page.assert_selector 'a,button', text: 'Pause'
+    find('a,button', text: 'Pause').click
 
     # Pipeline is stopped. It should now be in paused state and Runnable again.
     assert page.has_text? 'Paused'
     page.assert_no_selector 'a.disabled,button.disabled', text: 'Resume'
-    page.assert_selector 'a,button', text: 'Clone and edit'
+    page.assert_selector 'a,button', text: 'Re-run with latest'
 
     # Since it is test env, no jobs are created to run. So, graph not visible
     assert_not page.has_text? 'Graph'
@@ -136,9 +136,9 @@ class PipelineInstancesTest < ActionDispatch::IntegrationTest
     page.assert_no_selector 'a.disabled,button.disabled', text: 'Run'
     first('a,button', text: 'Run').click
 
     # Pipeline is running. We have a "Stop" button instead now.
     page.assert_no_selector 'a,button', text: 'Run'
-    page.assert_selector 'a,button', text: 'Stop'
+    page.assert_selector 'a,button', text: 'Pause'
 
     # Since it is test env, no jobs are created to run. So, graph not visible
     assert_not page.has_text? 'Graph'

-----------------------------------------------------------------------
@@ -136,9 +136,9 @@ class PipelineInstancesTest < ActionDispatch::IntegrationTest
     first('a,button', text: 'Run').click
 
-    # Pipeline is running. We have a "Stop" button instead now.
+    # Pipeline is running. We have a "Pause" button instead now.
     page.assert_no_selector 'a,button', text: 'Run'


hooks/post-receive
-- 




More information about the arvados-commits mailing list